@@ -21,10 +21,8 @@
 #ifndef XDG_DESKTOP_PORTAL_KDE_APPCHOOSER_DIALOG_H
 #define XDG_DESKTOP_PORTAL_KDE_APPCHOOSER_DIALOG_H
 
-#include <QAbstractListModel>
 #include <QDialog>
 
-class AppChooserDialogItem;
 class QGridLayout;
 
 class AppChooserDialog : public QDialog
